@@ -85,7 +85,8 @@ def main() -> None:
     be configured as a profile in the .kiwi metadata and added
     as effective build target in the package configuration file:
 
-        Defaults.get_cloud_builder_metadata_file_name()
+        └── Defaults.get_cloud_builder_meta_dir()
+             └── Defaults.get_cloud_builder_metadata_file_name()
 
     An example package config to build the xclock package
     for the Tumbleweed distribution for x86_64 and aarch64
@@ -162,7 +163,8 @@ def main() -> None:
 
     The directory containing the image config file:
 
-        Defaults.get_cloud_builder_metadata_file_name()
+        └── Defaults.get_cloud_builder_meta_dir()
+             └── Defaults.get_cloud_builder_metadata_file_name()
 
     is treated as the image description and passed as such to the
     KIWI image builder via cb-image. KIWI searches for a *.kiwi file
@@ -451,7 +453,8 @@ def is_request_valid(
 
     # 2. Check on project metadata to exist
     project_metadata = os.path.join(
-        project_source_path, Defaults.get_cloud_builder_metadata_file_name()
+        project_source_path, Defaults.get_cloud_builder_meta_dir(),
+        Defaults.get_cloud_builder_metadata_file_name()
     )
     if not os.path.isfile(project_metadata):
         response.set_project_metadata_not_existing_response(
